summaryrefslogtreecommitdiff
path: root/elisp
diff options
context:
space:
mode:
authorMark Polesky <markpolesky@yahoo.com>2009-05-27 10:07:08 -0700
committerJohn Mandereau <john.mandereau@gmail.com>2009-06-02 15:17:02 +0200
commit4de166b926eb374623101ef8d80fb0f67444b019 (patch)
treee85b51403003a88478831c0e9e5449c0dff102bc /elisp
parentcc828ca37fa97fa670b0b5f3d91eabdbdcd0514e (diff)
Typos: Lilypond -> LilyPond, explicite -> explicit, fix docstring
Diffstat (limited to 'elisp')
-rw-r--r--elisp/lilypond-mode.el4
1 files changed, 2 insertions, 2 deletions
diff --git a/elisp/lilypond-mode.el b/elisp/lilypond-mode.el
index 97778dc460..6736238ecb 100644
--- a/elisp/lilypond-mode.el
+++ b/elisp/lilypond-mode.el
@@ -32,7 +32,7 @@
"File prefix for commands on buffer or region.")
(defvar LilyPond-master-file nil
- "Master file that Lilypond will be run on.")
+ "Master file that LilyPond will be run on.")
;; FIXME: find ``\score'' in buffers / make settable?
(defun LilyPond-get-master-file ()
@@ -756,7 +756,7 @@ command."
(define-key LilyPond-mode-map "\C-cb" 'LilyPond-what-beat)
(define-key LilyPond-mode-map "\C-cf" 'font-lock-fontify-buffer)
(define-key LilyPond-mode-map "\C-ci" 'LilyPond-insert-tag-current)
;; the following will should be overriden by Lilypond Quick Insert Mode
(define-key LilyPond-mode-map "\C-cq" 'LilyPond-quick-insert-mode)
(define-key LilyPond-mode-map "\C-c;" 'LilyPond-comment-region)
(define-key LilyPond-mode-map ")" 'LilyPond-electric-close-paren)
@@ -756,7 +756,7 @@ command."
(define-key LilyPond-mode-map "\C-cf" 'font-lock-fontify-buffer)
(define-key LilyPond-mode-map "\C-ci" 'LilyPond-insert-tag-current)
- ;; the following will should be overriden by Lilypond Quick Insert Mode
+ ;; the following will should be overridden by LilyPond Quick Insert Mode
(define-key LilyPond-mode-map "\C-cq" 'LilyPond-quick-insert-mode)
(define-key LilyPond-mode-map "\C-c;" 'LilyPond-comment-region)